Span

Struct Span 

pub struct Span {
    pub range: TextRange,
    pub anchor: SpanAnchor,
    pub ctx: SyntaxContext,
}
Spans represent a region of code, used by the IDE to be able link macro inputs and outputs together. Positions in spans are relative to some SpanAnchor to make them more incremental friendly.

Fields

range: TextRange

The text range of this span, relative to the anchor. We need the anchor for incrementality, as storing absolute ranges will require recomputation on every change in a file at all times.

anchor: SpanAnchor

The anchor this span is relative to.

ctx: SyntaxContext

The syntax context of the span.

Implementations

Source

impl Span

pub fn cover(self, other: Span) -> Span

pub fn join( self, other: Span, differing_anchor: impl FnOnce(Span, Span) -> Option<Span>, ) -> Option<Span>

pub fn eq_ignoring_ctx(self, other: Self) -> bool