SpanMap

Struct SpanMap 

pub struct SpanMap {
    pub matched_arm: Option<u32>,
    /* private fields */
}
Maps absolute text ranges for the corresponding file to the relevant span data.

Fields

matched_arm: Option<u32>

Index of the matched macro arm on successful expansion for declarative macros.

Implementations

Source

impl SpanMap

pub fn empty() -> Self

Creates a new empty SpanMap.

pub fn finish(&mut self)

Finalizes the SpanMap, shrinking its backing storage and validating that the offsets are in order.

pub fn push(&mut self, offset: TextSize, span: Span)

Pushes a new span onto the SpanMap.

pub fn ranges_with_span_exact( &self, span: Span, ) -> impl Iterator<Item = (TextRange, SyntaxContext)> + '_

Returns all TextRanges that correspond to the given span.

Note this does a linear search through the entire backing vector.

pub fn ranges_with_span( &self, span: Span, ) -> impl Iterator<Item = (TextRange, SyntaxContext)> + '_

Returns all TextRanges whose spans contain the given span.

Note this does a linear search through the entire backing vector.

pub fn span_at(&self, offset: TextSize) -> Span

Returns the span at the given position.

pub fn spans_for_range( &self, range: TextRange, ) -> impl Iterator<Item = Span> + '_

Returns the spans associated with the given range. In other words, this will return all spans that correspond to all offsets within the given range.

pub fn iter(&self) -> impl Iterator<Item = (TextSize, Span)> + '_

pub fn merge( &mut self, other_range: TextRange, other_size: TextSize, other: &SpanMap, )

Merges this span map with another span map, where other is inserted at (and replaces) other_range.

The length of the replacement node needs to be other_size.