pub struct Span {
pub range: TextRange,
pub anchor: SpanAnchor,
pub ctx: SyntaxContext,
}Expand description
Spans represent a region of code, used by the IDE to be able link macro inputs and outputs
together. Positions in spans are relative to some SpanAnchor to make them more incremental
friendly.
Fields
range: TextRangeThe text range of this span, relative to the anchor. We need the anchor for incrementality, as storing absolute ranges will require recomputation on every change in a file at all times.
anchor: SpanAnchorThe anchor this span is relative to.
ctx: SyntaxContextThe syntax context of the span.
Implementations