Struct ra_ap_span::SpanMap
source · pub struct SpanMap<S> { /* private fields */ }Expand description
Maps absolute text ranges for the corresponding file to the relevant span data.
Implementations
sourceimpl<S: Copy> SpanMap<S>
impl<S: Copy> SpanMap<S>
sourcepub fn finish(&mut self)
pub fn finish(&mut self)
Finalizes the SpanMap, shrinking its backing storage and validating that the offsets are
in order.
sourcepub fn ranges_with_span(&self, span: S) -> impl Iterator<Item = TextRange> + '_where
S: Eq,
pub fn ranges_with_span(&self, span: S) -> impl Iterator<Item = TextRange> + '_where
S: Eq,
Returns all TextRanges that correspond to the given span.
Note this does a linear search through the entire backing vector.
sourcepub fn spans_for_range(&self, range: TextRange) -> impl Iterator<Item = S> + '_
pub fn spans_for_range(&self, range: TextRange) -> impl Iterator<Item = S> + '_
Returns the spans associated with the given range. In other words, this will return all spans that correspond to all offsets within the given range.
pub fn iter(&self) -> impl Iterator<Item = (TextSize, S)> + '_